@@ -18,6 +18,7 @@ class _AbstractPlotter(ABC):
     layers: Dict[str, Union[Layer2D, Layer3D]]
     output_directory: str
     handle_out_of_bounds: THandleOutOfBounds
+    include_comments: bool
 
     def __init__(
         self,
@@ -29,6 +30,7 @@ class _AbstractPlotter(ABC):
         feed_rate: float,
         handle_out_of_bounds: THandleOutOfBounds,
         output_directory: str,
+        include_comments: bool,
     ):
         self.title = title
         self.x_min = x_min
@@ -39,6 +41,7 @@ class _AbstractPlotter(ABC):
         self.layers = {}
         self.output_directory = output_directory
         self.handle_out_of_bounds = handle_out_of_bounds
+        self.include_comments = include_comments
 
     def get_min_and_max_points(
         self,
@@ -87,21 +90,23 @@ class _AbstractPlotter(ABC):
         - color (str) : A hex color (such as `#00FF00`) or human-readable color name
             (see [MatplotLib](https://matplotlib.org/stable/gallery/color/named_colors.html#css-colors)
             for a list of colors). Used with the `preview` method. Defaults to a random color if not provided.
-        - line_width (Optional[float]) : The width of the line to be plotted. Used with the `preview` method. Defaults to 2.0.
+        - line_width (Optional[float]) : The width of the line to be plotted. Used with the `preview` method. Defaults to`2.0`.
         - preview_only (bool) : Whether the layer is a preview layer. Preview layers show the
-            plotter head in motion but do not come in contact with plotting surface. Defaults to `False`.
+            plotter head in motion but do not come in contact with
+            [plotting surface](https://travisbumgarner.github.io/gcode2dplotterart/docs/documentation/terminology#feed-rate). Defaults to `False`.
 
         Returns:
-        - Layer : The newly created layer. Allows for chaining of the layer's add methods.
+        - Layer : The newly created [layer](https://travisbumgarner.github.io/gcode2dplotterart/docs/documentation/terminology#layer).
+          Allows for chaining of the layer's add methods.
         """
 
         pass
 
-    def add_preview_layer(self) -> None:
+    def _add_preview_layer(self) -> None:
         """
         Creates a new layer titled preview. The preview layer outlines the
         plotting area and plots an X through the middle without plotting anything.
-        Useful for checking the the plotting surface is flat.
+        Useful for checking the the [plotting surface](https://travisbumgarner.github.io/gcode2dplotterart/docs/documentation/terminology#feed-rate) is flat.
         """
         points = self.get_min_and_max_points()
 
@@ -158,36 +163,63 @@ class _AbstractPlotter(ABC):
 
         Returns:
         - dict: {"layer" : {"setup": [], "plotting": [], "teardown": []}}
-            A dictionary of dictionaries containing the setup, plotting, and teardown instructions as an array of
-            G-Code instruction strings per layer. Mostly used for testing purposes.
+            A dictionary of dictionaries containing
+            [instruction phases](https://travisbumgarner.github.io/gcode2dplotterart/docs/documentation/terminology#instruction-phase) - setup, plotting,
+            and teardown as an array of G-Code instruction strings per layer. Mostly used for testing purposes.
         """
 
         # Creates a new layer titled preview
-        self.add_preview_layer()
+        self._add_preview_layer()
 
         output = {}
         for title, layer in self.layers.items():
             output[title] = layer.get_plotting_data()
         return output
 
-    def preview(self) -> None:
+    def preview(self, show_entire_plotting_area: bool = True) -> None:
         """
-        Generate a preview graph of the plotter's layers. Layers will be plotted in the order they've been added to the
-        `Plotter`. Only looks at instructions during the plotting phase.
+        Generate a preview image of the plotter's layers. Layers will be plotted in the order they've been added to the `Plotter`.
+        Only looks at instructions during the `plotting` phase.
+
+        Args:
+        - show_entire_plotting_area (bool, optional): Whether to show the entire plotting area or just the
+          size of the art to be plotted. Defaults to `True`.
         """
 
+        _, ax = plt.subplots()
+
         for layer_title in self.layers:
             preview_paths = self.layers[layer_title].preview_paths()
             for preview_path in preview_paths:
+                print(preview_path)
                 x_values, y_values = zip(*preview_path)
-                plt.plot(
-                    x_values,
-                    y_values,
-                    color=self.layers[layer_title].color,
-                    linestyle="-",
-                    linewidth=self.layers[layer_title].line_width,
-                    solid_capstyle="round",
-                )
+
+                if (len(x_values)) == 1:
+                    # A single point does not plot on ax.plot()
+                    ax.scatter(
+                        x_values,
+                        y_values,
+                        color=self.layers[layer_title].color,
+                        s=self.layers[layer_title].line_width,
+                    )
+                else:
+                    ax.plot(
+                        x_values,
+                        y_values,
+                        color=self.layers[layer_title].color,
+                        linestyle="-",
+                        linewidth=self.layers[layer_title].line_width,
+                        solid_capstyle="round",
+                    )
+
+        if show_entire_plotting_area:
+            plt.xlim(self.x_min - 10, self.x_max + 10)
+            plt.ylim(self.y_min - 10, self.y_max + 10)
+
+        ax.spines["top"].set_visible(False)
+        ax.spines["right"].set_visible(False)
+        ax.spines["bottom"].set_visible(False)
+        ax.spines["left"].set_visible(False)
 
         plt.gca().set_aspect("equal", adjustable="box")
 
@@ -202,8 +234,8 @@ class _AbstractPlotter(ABC):
 
         Args:
         - clear_output_before_save (bool, optional): Whether to remove all files from the artwork output directory
-            (defined as `[output_directory]/[title]`) before saving. Defaults to True.
-        - include_layer_number (bool, optional): Whether to prepend filename with `layer_number`. Defaults to True.
+            (defined as `[output_directory]/[title]`) before saving. Defaults to `True`.
+        - include_layer_number (bool, optional): Whether to prepend filename with `layer_number`. Defaults to `True`.
         """
 
         artwork_directory = os.path.join(self.output_directory, self.title)
@@ -212,9 +244,14 @@ class _AbstractPlotter(ABC):
         if not os.path.exists(artwork_directory):
             os.makedirs(artwork_directory)
 
-        self.add_preview_layer()
+        self._add_preview_layer()
 
-        for index, title in enumerate(self.layers.keys()):
+        # Set preview layer as first
+        titles = list(self.layers.keys())
+        titles.remove("preview")
+        titles.insert(0, "preview")
+
+        for index, title in enumerate(titles):
             file_name = f"{title}.gcode"
             if include_layer_number:
                 file_name = f"{index}_" + file_name
@@ -240,6 +277,7 @@ class Plotter2D(_AbstractPlotter):
         feed_rate: float,
         handle_out_of_bounds: THandleOutOfBounds = "Warning",
         output_directory: str = "./output",
+        include_comments: bool = True,
     ) -> None:
         """
         Args:
@@ -248,13 +286,15 @@ class Plotter2D(_AbstractPlotter):
         - y_min (float) : The minimum Y-coordinate of the plotter.
         - x_max (float) : The maximum X-coordinate of the plotter.
         - y_max (float) : The maximum Y-coordinate of the plotter.
-        - feed_rate (float) : The feed rate for the plotter.
+        - feed_rate (float) : The [feed rate](https://travisbumgarner.github.io/gcode2dplotterart/docs/documentation/terminology#feed-rate), for the plotter.
         - handle_out_of_bounds (`Warning` | `Error`, optional):
             How to handle out-of-bounds points.
             `Warning` will print a warning, skip the point, and continue.
             `Error` will throw an error and stop.
             Defaults to `Warning`.
         - output_directory (str, optional) : The directory where G-code files will be saved. Defaults to `./output`.
+        - include_comments (bool, optional) : Whether to include comments in the G-Code files. Useful for learning about G-Code and debugging.
+          Defaults to `True`.
         """
 
         super().__init__(
@@ -266,6 +306,7 @@ class Plotter2D(_AbstractPlotter):
             feed_rate=feed_rate,
             handle_out_of_bounds=handle_out_of_bounds,
             output_directory=output_directory,
+            include_comments=include_comments,
         )
 
     def add_layer(
@@ -276,15 +317,16 @@ class Plotter2D(_AbstractPlotter):
         preview_only: bool = False,
     ) -> Layer2D:
         new_layer = Layer2D(
-            x_min=self.x_min,
-            x_max=self.x_max,
-            y_min=self.y_min,
-            y_max=self.y_max,
+            plotter_x_min=self.x_min,
+            plotter_x_max=self.x_max,
+            plotter_y_min=self.y_min,
+            plotter_y_max=self.y_max,
             feed_rate=self.feed_rate,
             handle_out_of_bounds=self.handle_out_of_bounds,
             preview_only=preview_only,
             line_width=line_width,
             color=color,
+            include_comments=self.include_comments,
         )
         self.layers[title] = new_layer
 
@@ -313,6 +355,7 @@ class Plotter3D(_AbstractPlotter):
         feed_rate: float,
         handle_out_of_bounds: THandleOutOfBounds = "Warning",
         output_directory: str = "./output",
+        include_comments: bool = True,
     ) -> None:
         """
         Initializes a new instance of the Plotter3D class.
@@ -323,15 +366,21 @@ class Plotter3D(_AbstractPlotter):
         - y_min (float) : The minimum Y-coordinate of the plotter.
         - x_max (float) : The maximum X-coordinate of the plotter.
         - y_max (float) : The maximum Y-coordinate of the plotter.
-        - z_plotting_height (float) : The height of the drawing instrument when plotting on the plotting surface.
-        - z_navigation_height (float) : The height of the drawing instrument when navigating to a new location.
-        - feed_rate (float) : The feed rate for the plotter.
+        - z_plotting_height (float) : The height of the
+          [plotting instrument](https://travisbumgarner.github.io/gcode2dplotterart/docs/documentation/terminology#instruction-phase) when plotting on the
+          [plotting surface](https://travisbumgarner.github.io/gcode2dplotterart/docs/documentation/terminology#feed-rate).
+        - z_navigation_height (float) : The height of the
+          [plotting instrument](https://travisbumgarner.github.io/gcode2dplotterart/docs/documentation/terminology#instruction-phase) when navigating
+          to a new location.
+        - feed_rate (float) : The [feed rate](https://travisbumgarner.github.io/gcode2dplotterart/docs/documentation/terminology#feed-rate), for the plotter.
         - handle_out_of_bounds (`Warning` | `Error`, optional):
           How to handle out-of-bounds points.
           `Warning` will print a warning, skip the point, and continue.
           `Error` will throw an error and stop.
           Defaults to `Warning`.
         - output_directory (str, optional) : The directory where G-code files will be saved. Defaults to `./output`.
+        - include_comments (bool, optional) : Whether to include comments in the G-Code files. Useful for learning about G-Code and debugging. D
+          efaults to `True`.
         """
 
         super().__init__(
@@ -343,6 +392,7 @@ class Plotter3D(_AbstractPlotter):
             feed_rate=feed_rate,
             handle_out_of_bounds=handle_out_of_bounds,
             output_directory=output_directory,
+            include_comments=include_comments,
         )
         self.z_plotting_height = z_plotting_height
         self.z_navigation_height = z_navigation_height
@@ -359,19 +409,19 @@ class Plotter3D(_AbstractPlotter):
 
         Args:
         - title (str): The title of the layer.
-        - color (Optional[str], optional): The color of the layer. Defaults to None.
-        - line_width (float, optional): The line width of the layer. Defaults to 2.0.
-        - preview_only (bool, optional): Whether the layer is for preview only. Defaults to False.
+        - color (Optional[str], optional): The color of the layer. Defaults to `None`.
+        - line_width (float, optional): The line width of the layer. Defaults to `2.0`.
+        - preview_only (bool, optional): Whether the layer is for preview only. Defaults to `False`.
 
         Returns:
-        - Layer3D: The newly created layer.
+        - Layer3D: The newly created [layer](https://travisbumgarner.github.io/gcode2dplotterart/docs/documentation/terminology#layer).
         """
 
         new_layer = Layer3D(
-            x_min=self.x_min,
-            x_max=self.x_max,
-            y_min=self.y_min,
-            y_max=self.y_max,
+            plotter_x_min=self.x_min,
+            plotter_x_max=self.x_max,
+            plotter_y_min=self.y_min,
+            plotter_y_max=self.y_max,
             feed_rate=self.feed_rate,
             handle_out_of_bounds=self.handle_out_of_bounds,
             preview_only=preview_only,
@@ -379,6 +429,7 @@ class Plotter3D(_AbstractPlotter):
             z_plotting_height=self.z_plotting_height,
             z_navigation_height=self.z_navigation_height,
             color=color,
+            include_comments=self.include_comments,
         )
 
         self.layers[title] = new_layer
